Module lua

Module lua 

Available on crate feature luau only.
Contains definitions from lua.h.

Structs

lua_Callbacks
lua_Debug
lua_State
A raw Lua state associated with a thread.

Constants

LUA_BREAK
LUA_COERR
LUA_COFIN
LUA_CONOR
LUA_CORUN
LUA_COSUS
LUA_ENVIRONINDEX
LUA_ERRERR
LUA_ERRMEM
LUA_ERRRUN
LUA_ERRSYNTAX
LUA_GCCOLLECT
LUA_GCCOUNT
LUA_GCCOUNTB
LUA_GCISPAUSED
LUA_GCISRUNNING
LUA_GCRESTART
LUA_GCSETGOAL
LUA_GCSETSTEPMUL
LUA_GCSETSTEPSIZE
LUA_GCSTEP
LUA_GCSTOP
LUA_GLOBALSINDEX
LUA_LUTAG_LIMIT
LUA_MINSTACK
Guaranteed number of Lua stack slots available to a C function.
LUA_MULTRET
LUA_NOREF
LUA_OK
LUA_REFNIL
LUA_REGISTRYINDEX
LUA_TBOOLEAN
LUA_TBUFFER
LUA_TFUNCTION
LUA_TINTEGER
LUA_TLIGHTUSERDATA
LUA_TNIL
LUA_TNONE
LUA_TNUMBER
LUA_TSTRING
LUA_TTABLE
LUA_TTHREAD
LUA_TUSERDATA
LUA_TVECTOR
LUA_UTAG_LIMIT
LUA_YIELD

Functions

lua_absindex⚠
lua_allocationrate⚠
lua_atbreakpoint⚠
lua_break⚠
lua_breakpoint⚠
lua_call⚠
lua_callbacks⚠
lua_callhook⚠
lua_callyieldable⚠
lua_checkstack⚠
lua_cleartable⚠
lua_clock⚠
lua_clonefunction⚠
lua_clonetable⚠
lua_close⚠
lua_concat⚠
lua_costatus⚠
lua_cpcall⚠
lua_createtable⚠
lua_debugtrace⚠
lua_encodepointer⚠
lua_equal⚠
lua_error⚠
lua_gc⚠
lua_getallocf⚠
lua_getargument⚠
lua_getcounters⚠
lua_getcoverage⚠
lua_getfenv⚠
lua_getfield⚠
lua_getglobal⚠
lua_getinfo⚠
lua_getlightuserdataname⚠
lua_getlocal⚠
lua_getmetatable⚠
lua_getmetatablepointer⚠
lua_getreadonly⚠
lua_gettable⚠
lua_getthreaddata⚠
lua_gettop⚠
lua_getupvalue⚠
lua_getuserdatadtor⚠
lua_getuserdatametatable⚠
lua_getuserdataname⚠
lua_getweakref⚠
lua_hascustomexecution⚠
lua_incustomexecution⚠
lua_insert⚠
lua_isLfunction⚠
lua_isboolean⚠
lua_isbuffer⚠
lua_iscfunction⚠
lua_isfunction⚠
lua_isinteger64⚠
lua_islightuserdata⚠
lua_isnil⚠
lua_isnone⚠
lua_isnoneornil⚠
lua_isnumber⚠
lua_isstring⚠
lua_istable⚠
lua_isthread⚠
lua_isthreadreset⚠
lua_isuserdata⚠
lua_isvector⚠
lua_isyieldable⚠
lua_lessthan⚠
lua_lightuserdatatag⚠
lua_mainthread⚠
lua_memorydump⚠
lua_namecallatom⚠
lua_newbuffer⚠
lua_newstate⚠
lua_newtable⚠
lua_newthread⚠
lua_newuserdata⚠
lua_newuserdata_t⚠
lua_newuserdatadtor⚠
lua_newuserdatatagged⚠
lua_newuserdatataggedwithmetatable⚠
lua_next⚠
lua_objlen⚠
lua_objlen_⚠
lua_pcall⚠
lua_pcallyieldable⚠
lua_pop⚠
lua_pushboolean⚠
lua_pushcclosure⚠
lua_pushcclosured⚠
lua_pushcclosurek⚠
lua_pushcfunction⚠
lua_pushcfunctiond⚠
lua_pushfstring⚠
lua_pushinteger64⚠
lua_pushinteger_⚠
lua_pushlightuserdata⚠
lua_pushlightuserdatatagged⚠
lua_pushliteral⚠
lua_pushlstring_⚠
lua_pushnil⚠
lua_pushnumber⚠
lua_pushstring_⚠
lua_pushthread⚠
lua_pushunsigned⚠
lua_pushvalue⚠
lua_pushvector⚠Non-luau-vector4
lua_rawcheckstack⚠
lua_rawequal⚠
lua_rawget⚠
lua_rawgetfield⚠
lua_rawgeti_⚠
lua_rawgetptagged⚠
lua_rawiter⚠
lua_rawset⚠
lua_rawsetfield⚠
lua_rawseti_⚠
lua_rawsetptagged⚠
lua_ref⚠
lua_remove⚠
lua_replace⚠
lua_resetthread⚠
lua_resume_⚠
lua_resumeerror⚠
lua_setembeddergc⚠
lua_setfenv⚠
lua_setfield⚠
lua_setglobal⚠
lua_setlightuserdataname⚠
lua_setlocal⚠
lua_setmemcat⚠
lua_setmetatable⚠
lua_setpointerencodekey⚠
lua_setreadonly⚠
lua_setsafeenv⚠
lua_settable⚠
lua_setthreaddata⚠
lua_settop⚠
lua_setupvalue⚠
lua_setuserdatadtor⚠
lua_setuserdatamark⚠
lua_setuserdatametatable⚠
lua_setuserdatatag⚠
lua_singlestep⚠
lua_stackdepth⚠
lua_status⚠
lua_strlen⚠
lua_toboolean⚠
lua_tobuffer⚠
lua_tocfunction⚠
lua_tointeger64⚠
lua_tointeger_⚠
lua_tointegerx_⚠
lua_tolightuserdata⚠
lua_tolightuserdatatagged⚠
lua_tolstring⚠
lua_tolstringatom⚠
lua_tonumber⚠
lua_tonumberx⚠
lua_topointer⚠
lua_tostring⚠
lua_tostringatom⚠
lua_totalbytes⚠
lua_tothread⚠
lua_tounsigned⚠
lua_tounsignedx⚠
lua_touserdata⚠
lua_touserdatatagged⚠
lua_tovector⚠
lua_type⚠
lua_typename⚠
lua_unref⚠
lua_upvalueindex
lua_userdatatag⚠
lua_usesexport⚠
lua_weakref⚠
lua_weakunref⚠
lua_xmove⚠
lua_xpush⚠
lua_yield⚠
luau_load⚠
luau_setfflag⚠
luau_version
Returns Luau release version (eg. 0.xxx).

Type Aliases

lua_Alloc
Type for memory-allocation functions (no unwinding).
lua_CFunction
Type for native C functions that can be passed to Lua.
lua_CategoryName
lua_Continuation
lua_CounterFunction
lua_CounterValue
lua_Coverage
lua_Destructor
Type for userdata destructor functions (no unwinding).
lua_EmbedderGc
lua_EmbedderMark
lua_Hook
Type for functions to be called on debug events.
lua_Integer64-bit
lua_Number
A Lua number, usually equivalent to f64.
lua_Unsigned
A Lua unsigned integer, equivalent to u32.
lua_UserdataMark